*** Program: Interactions between effect modifier (category) and exposure(spline) in a Cox survival model

*** Last update: Dec 15, 2014 by Yingying Sang (Johns Hopkins Bloomberg School of Public Health, ysang1@jhu.edu)
******************************************************************************************************************

program spline_intx
version 11
syntax varlist(min=2 max=2) [if] [in], xrange(numlist) ref(real) [cmd(string) cmdopt(string) knot(numlist) fu(varname) outcome(varname) level(integer 1) covar(varlist fv) ///
       low(real -1000000) up(real 1000000) name(string) nograph eform legendorder(string asis) yl(numlist) xl(numlist) pos(integer 1) ring(real 0) noshave *]
preserve
marksample touse
keep if `touse'
if _N==0 {
   display "No observations"
   exit
   }
if "`fu'"!="" capture stset `fu', failure(`outcome')
capture list _st
if _rc>0 {
   display "Data not stset!"
   exit
   }
if ~inlist("`cmd'","","stcox","streg","stcrreg") {
   display "command not allowed"
   exit
   }
tempvar modifier indvar indvarcat modcat s
tokenize "`varlist'"
local modifier `1'
gen `indvar'=`2'
local indvarname "`2'"
local c=wordcount("`covar'")
if "`cmd'"=="" local cmd "stcox"
if "`knot'"!="" {
   local a:word count `knot'
   tokenize "`knot'"
   forvalues i=1/`a' {
      local spline "`spline'`indvar'`i' ``i'' "
      }
   local spline "`spline'`indvar'`=`a'+1'=`indvar'"
   mkspline `spline'
   forvalues k=1/`level' {
      forvalues i=1/`=`a'+1' {
	      gen `indvar'`i'int`k'=`indvar'`i'*(`modifier'==`k')
	      }
	   }
      tokenize `knot'
      if `ref'<`1' replace `indvar'1=`indvar'1-`ref'
      else {
         qui replace `indvar'1=`indvar'1-`1'
         if `a'>1 {
	        forvalues i=2/`a' {
	           if `ref'>``i'' qui replace `indvar'`i'=`indvar'`i'-``i''+``=`i'-1''
	           else {
		          qui replace `indvar'`i'=`indvar'`i'-`ref'+``=`i'-1''
	              continue, break
			      }
			   }
		    }
	     if `ref'>``a'' qui replace `indvar'`=`a'+1'=`indvar'`=`a'+1'-`ref'+``a''
		 }
   }
else {
   local a=0
   forvalues k=1/`level' {
	   gen `indvar'1int`k'=`indvar'*(`modifier'==`k')
	   }
   gen `indvar'1=`indvar'-`ref'
   }
capture noisily `cmd' `indvar'? i.`modifier' `indvar'?int? `covar', nolog `cmdopt'
if _rc!=0 exit
matrix beta=e(b)'
matrix cov=e(V)
keep if e(sample)
count if _d==1
if r(N)<10 {
   display "Not enough events"
   exit
   }
forvalues k=0/`level' {
   count if `modifier'==`k' & _d==1
   if r(N)<10 local ev`k' "Not enough events"
   }
if "`cmd'"!="stcrreg" predict double `s', basesurv
else {
   predict double `cif', basecif
   gen double `s'=1-`cif'
   }
foreach i of numlist 1(2)5 10 {
   sum `s' if _t<=`i'
   gen double s`i'=r(min)
   }
egen `indvarcat'=cut(`indvar'), at(`low' `knot' `up') label
tab2 `indvarcat' `modifier'
tab2 `indvarcat' `modifier' if _d
contract s1-s10 _d `modifier' `indvarcat'
reshape wide _freq, i(s1-s10 `modifier' `indvarcat') j(_d)
rename _freq0 participant
rename _freq1 event
gen `modcat'=`indvarcat'+`=`a'+1'*`modifier'
while _N<`=(`level'+1)*(`a'+1)' {
   qui set obs `=_N+1'
   forvalues i=1/`=_N-1' {
      if `modcat'[`i']!=`i'-1 {
	     qui replace `modcat'=`i'-1 in `=_N'
		 sort `modcat'
		 continue, break
		 }
	  }
   qui replace `modcat'=_N-1 if `modcat'==.
   }
qui replace participant=0 if participant==.
qui replace event=0 if event==.
qui replace participant=participant+event
qui replace `indvarcat'=mod(`modcat',`=`a'+1')
qui replace `modifier'=int(`modcat'/(`a'+1))
drop `modcat'
rename `indvarcat' `indvarname'cat
reshape wide participant event, i(s1-s10 `indvarname'cat) j(`modifier')
local obs:word count `xrange'
qui set obs `obs'
egen `indvar'=fill(`xrange')
set obs `=_N+1'
qui replace `indvar'=`ref' in `=_N'
egen `indvarcat'=cut(`indvar'), at(`low' `knot' `up') label
forvalues i=1/`obs' {
   if `indvar'[`i']<=`ref' & `indvar'[`=`i'+1']>`ref' local lr=`i'
   }
forvalues k=0/`level' {
   qui gen inr`k'=.
   forvalues i=1/`=`a'+1' {
      qui replace inr`k'=(event`k'[`i']==0) if `indvarcat'==`i'-1
	  }
   if "`ev`k''"!="" | inr`k'[_N]==1 qui replace inr`k'=1
   forvalues i=1/`=`lr'-1' {
      qui replace inr`k'=1 if inr`k'[`=`lr'-`i'+1']==1 in `=`lr'-`i''
      }
   forvalues i=`=`lr'+2'/`obs' {
      qui replace inr`k'=1 if inr`k'[`=`i'-1']==1 in `i'
      }
   }
forvalues k=1/`level' {
   gen inr`=`k'+`level''=inr`k' | inr0[_N]
   gen inr`=`k'+2*`level''=inr0 | inr`k'
   }
if "`knot'"!="" {
   mkspline `spline'
   forvalues i=1/`=`a'+1' {
      replace `indvar'`i'=`indvar'`i'-`indvar'`i'[_N] in 1/`=_N-1'
      forvalues k=1/`level' {
         gen `indvar'`i'int`k'=0	     
	     }
      }
   }
else {
   gen `indvar'1=`indvar'-`ref'
   qui replace `indvar'1=`ref' in `=_N'
   forvalues k=1/`level' {
      gen `indvar'1int`k'=0	     
	  }
   }
gen `modifier'=0
if `c'>0 {
   tokenize "`covar'"
   forvalues i=1/`c' {
      if strpos("``i''",".")==0 gen ``i''=0
	  if strpos("``i''",".")==2 {
	     local abc=substr("``i''",3,.)
		 gen `abc'=0
		 }
	  if strpos("``i''",".")==4 {
	     local abc=substr("``i''",5,.)
		 local z=substr("``i''",3,1)
		 gen `abc'=`z'
		 }		
	  }
   }
predict estimate0, xb
predict stderr0, stdp
forvalues k=1/`level' {
   forvalues i=1/`=`a'+1' {
      qui replace `indvar'`i'int`k'=`indvar'`i'
	  qui replace `indvar'`i'=0 in 1/`=_N-1'
	  }
   predict estimate`=`k'+2*`level'', xb
   predict stderr`=`k'+2*`level'', stdp
   forvalues i=1/`=`a'+1' {
      qui replace `indvar'`i'=`indvar'`i'int`k' in 1/`=_N-1'
	  }
   predict estimate`k', xb
   predict stderr`k', stdp
   forvalues i=1/`=`a'+1' {
      qui replace `indvar'`i'int`k'=`indvar'`i'+`indvar'`i'[_N] in 1/`=_N-1'
	  }
   qui replace `modifier'=`k'
   predict estimate`=`k'+`level'', xb
   predict stderr`=`k'+`level'', stdp
   qui replace `modifier'=0
   forvalues i=1/`=`a'+1' {
       qui replace `indvar'`i'int`k'=0
	  }
   }
drop in `=_N'
forvalues q=0/`=3*`level'' {
   qui replace inr`q'=2 if abs(estimate`q')>1.96*stderr`q' & inr`q'!=1
   gen hr`q'=exp(estimate`q')
   gen lci`q'=exp(estimate`q'-1.96*stderr`q')
   gen uci`q'=exp(estimate`q'+1.96*stderr`q')
   }
rename `indvar' `indvarname'
keep `indvarname' estimate* stderr* hr* lci* uci* inr*
save "`name'-estimate.dta", replace
if "`graph'"=="" {
if "`yl'"=="" local yl "0.5 1 1.5 2 4 8 16"
if `"`legendorder'"'=="" local legend "legend(off)"
else local legend `"legend(order(`legendorder') region(color(none)) position(`pos') ring(`ring') si(4))"'
tempvar minlci0 minlci1 minlci2 minlci3 a1 a2 a3 lc refc minlci4 minlci5 a4 a5
if "`shave'"=="" {
   local shlow=word("`yl'",1)
   local shup=word("`yl'",-1)
   forvalue k=0/`=2*`level'' {
      qui replace inr`k'=2.8 if  uci`k'>`shup' & uci`k'<. & inr`k'==2
      qui replace inr`k'=0.8 if  uci`k'>`shup' & uci`k'<. & inr`k'==0
      qui replace hr`k'=`shup' if hr`k'>`shup' & hr`k'<.
      qui replace uci`k'=`shup' if uci`k'>`shup' & uci`k'<.
      qui replace lci`k'=`shup' if lci`k'>`shup' & uci`k'<.
      qui replace inr`k'=2.3 if  lci`k'<`shlow' & inr`k'==2
      qui replace inr`k'=0.3 if  lci`k'<`shlow' & inr`k'==0
      qui replace hr`k'=`shlow' if hr`k'<`shlow'
      qui replace lci`k'=`shlow' if lci`k'<`shlow'
      qui replace uci`k'=`shlow' if uci`k'<`shlow'
	  }
   gen `a1'=`shlow'/(`shup'/`shlow')^0.05
   if `level'>1 {
      forvalues k=2/`level' {
	     gen `a`k''=`a`=`k'-1''/(`shup'/`shlow')^0.02
		 }
	  }
   }
else {
   forvalue k=0/`level' {
      egen `minlci`k''=min(lci`k') if inr`k'!=1
      }
   gen `a1'=min(`minlci0',`minlci1')/1.2
   if `level'>1 {
      forvalues k=2/`level' {
	     gen `a`k''=`a`=`k'-1''/1.1
		 }
	  }
   }
gen `lc'=1
if "`eform'"=="" gen `refc'=`ref'
else {
   gen `refc'=exp(`ref')
   replace `indvarname'=exp(`indvarname')
   }
forvalue k=0/`level' {
   replace hr`k'=1 if `indvarname'==`ref'
   replace lci`k'=1 if `indvarname'==`ref'
   replace uci`k'=1 if `indvarname'==`ref'
   }
if `level'==1 {
twoway  /// 
rarea lci0 uci0 `indvarname' if inr0!=1, color(gs14) graphregion(fcolor(white)) `legend'  ///
	ytitle("Adjusted HR",si(4) m(r+1)) xtitle("`xtitle'",si(4) m(t+1)) xlabel(`xl',labs(4)) ///
	ylabel(`yl',labs(4) angle(0)) yscale(log r(`shlow' `shup')) `options' || ///
rcap lci1 uci1 `indvarname' if inr1!=1, lcolor("230 170 170") lwidth(0.3)|| ///
line hr0 `indvarname' if inr0!=1, lw(0.3) lcolor(black) || ///
line hr1 `indvarname' if inr1!=1, lw(0.3) lcolor(red) || ///
scatter hr0 `indvarname' if inr0>=2,ms(O) msize(1) mlwidth(0.5) color(black) || ///
scatter hr1 `indvarname' if inr1>=2,ms(O) msize(1) mlwidth(0.5) color(red) || ///
scatter uci0 `indvarname' if (inr0>2.7 | inr0>0.7 & inr0<1), ms(x) mc(gs6) msize(1) || ///
scatter lci0 `indvarname' if (inr0<2.4 & inr0>2 | inr0>0 & inr0<0.4), ms(x) mc(gs6) msize(1) || ///
scatter uci1 `indvarname' if (inr1>2.7 | inr1>0.7 & inr1<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci1 `indvarname' if (inr1<2.4 & inr1>2 | inr1>0 & inr1<0.4), ms(x) mc("230 170 170") msize(1) || ///
scatter `a1' `indvarname' if inr3>=2, ms(T) msize(1) color(red) || ///
line `lc' `indvarname', lcolor(gray) || ///
scatter `lc' `refc', ms(D) msize(2) mc(black)
graph save "`name'-figure.gph",replace
more
twoway  /// 
rarea lci0 uci0 `indvarname' if inr0!=1, color(gs14) graphregion(fcolor(white)) `legend'  ///
	ytitle("Adjusted HR",si(4) m(r+1)) xtitle("`xtitle'",si(4) m(t+1)) xlabel(`xl',labs(4)) ///
	ylabel(`yl',labs(4) angle(0)) yscale(log r(`shlow' `shup')) `options' || ///
rcap lci2 uci2 `indvarname' if inr2!=1, lcolor("230 170 170") lwidth(0.3)|| ///
line hr0 `indvarname' if inr0!=1, lw(0.3) lcolor(black) || ///
line hr2 `indvarname' if inr2!=1, lw(0.3) lcolor(red) || ///
scatter hr0 `indvarname' if inr0>=2,ms(O) msize(1) mlwidth(0.5) color(black) || ///
scatter hr2 `indvarname' if inr2>=2,ms(O) msize(1) mlwidth(0.5) color(red) || ///
scatter uci0 `indvarname' if (inr0>2.7 | inr0>0.7 & inr0<1), ms(x) mc(gs6) msize(1) || ///
scatter lci0 `indvarname' if (inr0<2.4 & inr0>2 | inr0>0 & inr0<0.4), ms(x) mc(gs6) msize(1) || ///
scatter uci2 `indvarname' if (inr2>2.7 | inr2>0.7 & inr2<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci2 `indvarname' if (inr2<2.4 & inr2>2 | inr2>0 & inr2<0.4), ms(x) mc("230 170 170") msize(1) || ///
line `lc' `indvarname', lcolor(gray) || ///
scatter `lc' `refc', ms(D) msize(2) mc(black)
graph save "`name'-figure-main.gph",replace
}
if `level'==2 {
twoway  /// 
rarea lci0 uci0 `indvarname' if inr0!=1, color(gs14) graphregion(fcolor(white)) `legend'  ///
	ytitle("Adjusted HR",si(4) m(r+1)) xtitle("`xtitle'",si(4) m(t+1)) xlabel(`xl',labs(4)) ///
	ylabel(`yl',labs(4) angle(0)) yscale(log r(`shlow' `shup')) `options' || ///
rcap lci1 uci1 `indvarname' if inr1!=1, lcolor(ltblue) lwidth(0.3)|| ///
rcap lci2 uci2 `indvarname' if inr2!=1, lcolor("230 170 170") lwidth(0.3)|| ///
line hr0 `indvarname' if inr0!=1, lw(0.3) lcolor(black) || ///
line hr1 `indvarname' if inr1!=1, lw(0.3) lcolor(blue) || ///
line hr2 `indvarname' if inr2!=1, lw(0.3) lcolor(red) || ///
scatter hr0 `indvarname' if inr0>=2,ms(O) msize(1) mlwidth(0.5) color(black) || ///
scatter hr1 `indvarname' if inr1>=2,ms(O) msize(1) mlwidth(0.5) color(blue) || ///
scatter hr2 `indvarname' if inr2>=2,ms(O) msize(1) mlwidth(0.5) color(red) || ///
scatter uci0 `indvarname' if (inr0>2.7 | inr0>0.7 & inr0<1), ms(x) mc(gs6) msize(1) || ///
scatter lci0 `indvarname' if (inr0<2.4 & inr0>2 | inr0>0 & inr0<0.4), ms(x) mc(gs6) msize(1) || ///
scatter uci1 `indvarname' if (inr1>2.7 | inr1>0.7 & inr1<1), ms(x) mc(ltblue) msize(1) || ///
scatter lci1 `indvarname' if (inr1<2.4 & inr1>2 | inr1>0 & inr1<0.4), ms(x) mc(ltblue) msize(1) || ///
scatter uci2 `indvarname' if (inr2>2.7 | inr2>0.7 & inr2<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci2 `indvarname' if (inr2<2.4 & inr2>2 | inr2>0 & inr2<0.4), ms(x) mc("230 170 170") msize(1) || ///
scatter `a1' `indvarname' if inr5>=2, ms(T) msize(1) color(blue) || ///
scatter `a2' `indvarname' if inr6>=2, ms(T) msize(1) color(red) || ///
line `lc' `indvarname', lcolor(gray) || ///
scatter `lc' `refc', ms(D) msize(2) mc(black)
graph save "`name'-figure.gph",replace
more
twoway  /// 
rarea lci0 uci0 `indvarname' if inr0!=1, color(gs14) graphregion(fcolor(white)) `legend'  ///
	ytitle("Adjusted HR",si(4) m(r+1)) xtitle("`xtitle'",si(4) m(t+1)) xlabel(`xl',labs(4)) ///
	ylabel(`yl',labs(4) angle(0)) yscale(log r(`shlow' `shup')) `options' || ///
rcap lci3 uci3 `indvarname' if inr3!=1, lcolor(ltblue) lwidth(0.3)|| ///
rcap lci4 uci4 `indvarname' if inr4!=1, lcolor("230 170 170") lwidth(0.3)|| ///
line hr0 `indvarname' if inr0!=1, lw(0.3) lcolor(black) || ///
line hr3 `indvarname' if inr3!=1, lw(0.3) lcolor(blue) || ///
line hr4 `indvarname' if inr4!=1, lw(0.3) lcolor(red) || ///
scatter hr0 `indvarname' if inr0>=2,ms(O) msize(1) mlwidth(0.5) color(black) || ///
scatter hr3 `indvarname' if inr3>=2,ms(O) msize(1) mlwidth(0.5) color(blue) || ///
scatter hr4 `indvarname' if inr4>=2,ms(O) msize(1) mlwidth(0.5) color(red) || ///
scatter uci0 `indvarname' if (inr0>2.7 | inr0>0.7 & inr0<1), ms(x) mc(gs6) msize(1) || ///
scatter lci0 `indvarname' if (inr0<2.4 & inr0>2 | inr0>0 & inr0<0.4), ms(x) mc(gs6) msize(1) || ///
scatter uci3 `indvarname' if (inr3>2.7 | inr3>0.7 & inr3<1), ms(x) mc(ltblue) msize(1) || ///
scatter lci3 `indvarname' if (inr3<2.4 & inr3>2 | inr3>0 & inr3<0.4), ms(x) mc(ltblue) msize(1) || ///
scatter uci4 `indvarname' if (inr4>2.7 | inr4>0.7 & inr4<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci4 `indvarname' if (inr4<2.4 & inr4>2 | inr4>0 & inr4<0.4), ms(x) mc("230 170 170") msize(1) || ///
line `lc' `indvarname', lcolor(gray) || ///
scatter `lc' `refc', ms(D) msize(2) mc(black)
graph save "`name'-figure-main.gph",replace
}
if `level'==3 {
twoway  /// 
rarea lci0 uci0 `indvarname' if inr0!=1, color(gs14) graphregion(fcolor(white)) `legend'  ///
	ytitle("Adjusted HR",si(4) m(r+1)) xtitle("`xtitle'",si(4) m(t+1)) xlabel(`xl',labs(4)) ///
	ylabel(`yl',labs(4) angle(0)) yscale(log r(`shlow' `shup')) `options' || ///
rcap lci1 uci1 `indvarname' if inr1!=1, lcolor(ltblue) lwidth(0.3)|| ///
rcap lci2 uci2 `indvarname' if inr2!=1, lcolor("230 170 230") lwidth(0.3)|| ///
rcap lci3 uci3 `indvarname' if inr3!=1, lcolor("230 170 170") lwidth(0.3)|| ///
line hr0 `indvarname' if inr0!=1, lw(0.3) lcolor(black) || ///
line hr1 `indvarname' if inr1!=1, lw(0.3) lcolor(blue) || ///
line hr2 `indvarname' if inr2!=1, lw(0.3) lcolor(purple) || ///
line hr3 `indvarname' if inr3!=1, lw(0.3) lcolor(red) || ///
scatter hr0 `indvarname' if inr0>=2,ms(O) msize(1) mlwidth(0.5) color(black) || ///
scatter hr1 `indvarname' if inr1>=2,ms(O) msize(1) mlwidth(0.5) color(blue) || ///
scatter hr2 `indvarname' if inr2>=2,ms(O) msize(1) mlwidth(0.5) color(purple) || ///
scatter hr3 `indvarname' if inr3>=2,ms(O) msize(1) mlwidth(0.5) color(red) || ///
scatter uci0 `indvarname' if (inr0>2.7 | inr0>0.7 & inr0<1), ms(x) mc(gs6) msize(1) || ///
scatter lci0 `indvarname' if (inr0<2.4 & inr0>2 | inr0>0 & inr0<0.4), ms(x) mc(gs6) msize(1) || ///
scatter uci1 `indvarname' if (inr1>2.7 | inr1>0.7 & inr1<1), ms(x) mc(ltblue) msize(1) || ///
scatter lci1 `indvarname' if (inr1<2.4 & inr1>2 | inr1>0 & inr1<0.4), ms(x) mc(ltblue) msize(1) || ///
scatter uci2 `indvarname' if (inr2>2.7 | inr2>0.7 & inr2<1), ms(x) mc("230 170 230") msize(1) || ///
scatter lci2 `indvarname' if (inr2<2.4 & inr2>2 | inr2>0 & inr2<0.4), ms(x) mc("230 170 230") msize(1) || ///
scatter uci3 `indvarname' if (inr3>2.7 | inr3>0.7 & inr3<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci3 `indvarname' if (inr3<2.4 & inr3>2 | inr3>0 & inr3<0.4), ms(x) mc("230 170 170") msize(1) || ///
scatter `a1' `indvarname' if inr7>=2, ms(T) msize(1) color(blue) || ///
scatter `a2' `indvarname' if inr8>=2, ms(T) msize(1) color(purple) || ///
scatter `a3' `indvarname' if inr9>=2, ms(T) msize(1) color(red) || ///
line `lc' `indvarname', lcolor(gray) || ///
scatter `lc' `refc', ms(D) msize(2) mc(black)
graph save "`name'-figure.gph",replace
more
twoway  /// 
rarea lci0 uci0 `indvarname' if inr0!=1, color(gs14) graphregion(fcolor(white)) `legend'  ///
	ytitle("Adjusted HR",si(4) m(r+1)) xtitle("`xtitle'",si(4) m(t+1)) xlabel(`xl',labs(4)) ///
	ylabel(`yl',labs(4) angle(0)) yscale(log r(`shlow' `shup')) `options' || ///
rcap lci4 uci4 `indvarname' if inr4!=1, lcolor(ltblue) lwidth(0.3)|| ///
rcap lci5 uci5 `indvarname' if inr5!=1, lcolor("230 170 230") lwidth(0.3)|| ///
rcap lci6 uci6 `indvarname' if inr6!=1, lcolor("230 170 170") lwidth(0.3)|| ///
line hr0 `indvarname' if inr0!=1, lw(0.3) lcolor(black) || ///
line hr4 `indvarname' if inr4!=1, lw(0.3) lcolor(blue) || ///
line hr5 `indvarname' if inr5!=1, lw(0.3) lcolor(purple) || ///
line hr6 `indvarname' if inr6!=1, lw(0.3) lcolor(red) || ///
scatter hr0 `indvarname' if inr0>=2,ms(O) msize(1) mlwidth(0.5) color(black) || ///
scatter hr4 `indvarname' if inr4>=2,ms(O) msize(1) mlwidth(0.5) color(blue) || ///
scatter hr5 `indvarname' if inr5>=2,ms(O) msize(1) mlwidth(0.5) color(purple) || ///
scatter hr6 `indvarname' if inr6>=2,ms(O) msize(1) mlwidth(0.5) color(red) || ///
scatter uci0 `indvarname' if (inr0>2.7 | inr0>0.7 & inr0<1), ms(x) mc(gs6) msize(1) || ///
scatter lci0 `indvarname' if (inr0<2.4 & inr0>2 | inr0>0 & inr0<0.4), ms(x) mc(gs6) msize(1) || ///
scatter uci4 `indvarname' if (inr4>2.7 | inr4>0.7 & inr4<1), ms(x) mc(ltblue) msize(1) || ///
scatter lci4 `indvarname' if (inr4<2.4 & inr4>2 | inr4>0 & inr4<0.4), ms(x) mc(ltblue) msize(1) || ///
scatter uci5 `indvarname' if (inr5>2.7 | inr5>0.7 & inr5<1), ms(x) mc("230 170 230") msize(1) || ///
scatter lci5 `indvarname' if (inr5<2.4 & inr5>2 | inr5>0 & inr5<0.4), ms(x) mc("230 170 230") msize(1) || ///
scatter uci6 `indvarname' if (inr6>2.7 | inr6>0.7 & inr6<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci6 `indvarname' if (inr6<2.4 & inr6>2 | inr6>0 & inr6<0.4), ms(x) mc("230 170 170") msize(1) || ///
line `lc' `indvarname', lcolor(gray) || ///
scatter `lc' `refc', ms(D) msize(2) mc(black)
graph save "`name'-figure-main.gph",replace
}
if `level'==4 {
twoway  /// 
rarea lci0 uci0 `indvarname' if inr0!=1, color(gs14) graphregion(fcolor(white)) `legend'  ///
	ytitle("Adjusted HR",si(4) m(r+1)) xtitle("`xtitle'",si(4) m(t+1)) xlabel(`xl',labs(4)) ///
	ylabel(`yl',labs(4) angle(0)) yscale(log r(`shlow' `shup')) `options' || ///
rcap lci1 uci1 `indvarname' if inr1!=1, lcolor(ltblue) lwidth(0.3)|| ///
rcap lci2 uci2 `indvarname' if inr2!=1, lcolor("230 170 230") lwidth(0.3)|| ///
rcap lci3 uci3 `indvarname' if inr3!=1, lcolor("230 170 170") lwidth(0.3)|| ///
rcap lci4 uci4 `indvarname' if inr4!=1, lcolor("230 170 120") lwidth(0.3)|| ///
line hr0 `indvarname' if inr0!=1, lw(0.3) lcolor(black) || ///
line hr1 `indvarname' if inr1!=1, lw(0.3) lcolor(blue) || ///
line hr2 `indvarname' if inr2!=1, lw(0.3) lcolor(purple) || ///
line hr3 `indvarname' if inr3!=1, lw(0.3) lcolor(red) || ///
line hr4 `indvarname' if inr4!=1, lw(0.3) lcolor(orange) || ///
scatter hr0 `indvarname' if inr0>=2,ms(O) msize(1) mlwidth(0.5) color(black) || ///
scatter hr1 `indvarname' if inr1>=2,ms(O) msize(1) mlwidth(0.5) color(blue) || ///
scatter hr2 `indvarname' if inr2>=2,ms(O) msize(1) mlwidth(0.5) color(purple) || ///
scatter hr3 `indvarname' if inr3>=2,ms(O) msize(1) mlwidth(0.5) color(red) || ///
scatter hr4 `indvarname' if inr4>=2,ms(O) msize(1) mlwidth(0.5) color(orange) || ///
scatter uci0 `indvarname' if (inr0>2.7 | inr0>0.7 & inr0<1), ms(x) mc(gs6) msize(1) || ///
scatter lci0 `indvarname' if (inr0<2.4 & inr0>2 | inr0>0 & inr0<0.4), ms(x) mc(gs6) msize(1) || ///
scatter uci1 `indvarname' if (inr1>2.7 | inr1>0.7 & inr1<1), ms(x) mc(ltblue) msize(1) || ///
scatter lci1 `indvarname' if (inr1<2.4 & inr1>2 | inr1>0 & inr1<0.4), ms(x) mc(ltblue) msize(1) || ///
scatter uci2 `indvarname' if (inr2>2.7 | inr2>0.7 & inr2<1), ms(x) mc("230 170 230") msize(1) || ///
scatter lci2 `indvarname' if (inr2<2.4 & inr2>2 | inr2>0 & inr2<0.4), ms(x) mc("230 170 230") msize(1) || ///
scatter uci3 `indvarname' if (inr3>2.7 | inr3>0.7 & inr3<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci3 `indvarname' if (inr3<2.4 & inr3>2 | inr3>0 & inr3<0.4), ms(x) mc("230 170 170") msize(1) || ///
scatter uci4 `indvarname' if (inr4>2.7 | inr4>0.7 & inr4<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci4 `indvarname' if (inr4<2.4 & inr4>2 | inr4>0 & inr4<0.4), ms(x) mc("230 170 120") msize(1) || ///
scatter `a1' `indvarname' if inr9>=2, ms(T) msize(1) color(blue) || ///
scatter `a2' `indvarname' if inr10>=2, ms(T) msize(1) color(purple) || ///
scatter `a3' `indvarname' if inr11>=2, ms(T) msize(1) color(red) || ///
scatter `a4' `indvarname' if inr12>=2, ms(T) msize(1) color(orange) || ///
line `lc' `indvarname', lcolor(gray) || ///
scatter `lc' `refc', ms(D) msize(2) mc(black)
graph save "`name'-figure.gph",replace
more
twoway  /// 
rarea lci0 uci0 `indvarname' if inr0!=1, color(gs14) graphregion(fcolor(white)) `legend'  ///
	ytitle("Adjusted HR",si(4) m(r+1)) xtitle("`xtitle'",si(4) m(t+1)) xlabel(`xl',labs(4)) ///
	ylabel(`yl',labs(4) angle(0)) yscale(log r(`shlow' `shup')) `options' || ///
rcap lci5 uci5 `indvarname' if inr5!=1, lcolor(ltblue) lwidth(0.3)|| ///
rcap lci6 uci6 `indvarname' if inr6!=1, lcolor("230 170 230") lwidth(0.3)|| ///
rcap lci7 uci7 `indvarname' if inr7!=1, lcolor("230 170 170") lwidth(0.3)|| ///
rcap lci8 uci8 `indvarname' if inr8!=1, lcolor("230 170 120") lwidth(0.3)|| ///
line hr0 `indvarname' if inr0!=1, lw(0.3) lcolor(black) || ///
line hr5 `indvarname' if inr5!=1, lw(0.3) lcolor(blue) || ///
line hr6 `indvarname' if inr6!=1, lw(0.3) lcolor(purple) || ///
line hr7 `indvarname' if inr7!=1, lw(0.3) lcolor(red) || ///
line hr8 `indvarname' if inr8!=1, lw(0.3) lcolor(orange) || ///
scatter hr0 `indvarname' if inr0>=2,ms(O) msize(1) mlwidth(0.5) color(black) || ///
scatter hr5 `indvarname' if inr5>=2,ms(O) msize(1) mlwidth(0.5) color(blue) || ///
scatter hr6 `indvarname' if inr6>=2,ms(O) msize(1) mlwidth(0.5) color(purple) || ///
scatter hr7 `indvarname' if inr7>=2,ms(O) msize(1) mlwidth(0.5) color(red) || ///
scatter hr8 `indvarname' if inr8>=2,ms(O) msize(1) mlwidth(0.5) color(orange) || ///
scatter uci0 `indvarname' if (inr0>2.7 | inr0>0.7 & inr0<1), ms(x) mc(gs6) msize(1) || ///
scatter lci0 `indvarname' if (inr0<2.4 & inr0>2 | inr0>0 & inr0<0.4), ms(x) mc(gs6) msize(1) || ///
scatter uci5 `indvarname' if (inr5>2.7 | inr5>0.7 & inr5<1), ms(x) mc(ltblue) msize(1) || ///
scatter lci5 `indvarname' if (inr5<2.4 & inr5>2 | inr5>0 & inr5<0.4), ms(x) mc(ltblue) msize(1) || ///
scatter uci6 `indvarname' if (inr6>2.7 | inr6>0.7 & inr6<1), ms(x) mc("230 170 230") msize(1) || ///
scatter lci6 `indvarname' if (inr6<2.4 & inr6>2 | inr6>0 & inr6<0.4), ms(x) mc("230 170 230") msize(1) || ///
scatter uci7 `indvarname' if (inr7>2.7 | inr7>0.7 & inr7<1), ms(x) mc("230 170 170") msize(1) || ///
scatter lci7 `indvarname' if (inr7<2.4 & inr7>2 | inr7>0 & inr7<0.4), ms(x) mc("230 170 170") msize(1) || ///
scatter uci8 `indvarname' if (inr8>2.7 | inr8>0.7 & inr8<1), ms(x) mc("230 170 120") msize(1) || ///
scatter lci8 `indvarname' if (inr8<2.4 & inr8>2 | inr8>0 & inr8<0.4), ms(x) mc("230 170 120") msize(1) || ///
line `lc' `indvarname', lcolor(gray) || ///
scatter `lc' `refc', ms(D) msize(2) mc(black)
graph save "`name'-figure-main.gph",replace
}
}
end
